@@ -1,8 +1,8 @@
 context("diagnostics")
 
 test_that("clipr_available fails when DISPLAY is not configured; succeeds when it is", {
-  # Only run this test on Travis
-  skip_if_not(identical(Sys.getenv("TRAVIS"), "true"))
+  # Only run this test on Github Actions
+  skip_if_not(identical(Sys.getenv("GITHUB_ACTIONS"), "true"))
 
   # If this envar hasn't been set, confirm that is_clipr_available will be false
   # and write_clip will error
@@ -10,11 +10,13 @@ test_that("clipr_available fails when DISPLAY is not configured; succeeds when i
     expect_false(is_clipr_available)
     expect_error(write_clip("test"))
   } else {
-    if (identical(Sys.getenv("TRAVIS_CLIP"), "none"))
+    if (identical(Sys.getenv("CLIP_TYPE"), "none"))
       expect_false(is_clipr_available)
-    if (identical(Sys.getenv("TRAVIS_CLIP"), "xclip"))
+    if (identical(Sys.getenv("CLIP_TYPE"), "xclip"))
       expect_true(is_clipr_available)
-    if (identical(Sys.getenv("TRAVIS_CLIP"), "xsel"))
+    if (identical(Sys.getenv("CLIP_TYPE"), "xsel"))
+      expect_true(is_clipr_available)
+    if (identical(Sys.getenv("CLIP_TYPE"), "wayland"))
       expect_true(is_clipr_available)
   }
 })
@@ -23,13 +25,15 @@ test_that("dr_clipr provides informative messages", {
   if (identical(Sys.getenv("CLIPR_ALLOW"), "")) {
     expect_message(dr_clipr(), "CLIPR_ALLOW", fixed = TRUE)
   } else {
-    if (identical(Sys.getenv("TRAVIS_CLIP"), "xclip"))
+    if (identical(Sys.getenv("CLIP_TYPE"), "xclip"))
       expect_message(dr_clipr(), msg_clipr_available(), fixed = TRUE)
-    if (identical(Sys.getenv("TRAVIS_CLIP"), "xsel"))
+    if (identical(Sys.getenv("CLIP_TYPE"), "xsel"))
       expect_message(dr_clipr(), msg_clipr_available(), fixed = TRUE)
-    if (identical(Sys.getenv("TRAVIS_CLIP"), "none"))
+    if (identical(Sys.getenv("CLIP_TYPE"), "wayland"))
+      expect_message(dr_clipr(), msg_clipr_available(), fixed = TRUE)
+    if (identical(Sys.getenv("CLIP_TYPE"), "none"))
       expect_message(dr_clipr(), msg_no_clipboard(), fixed = TRUE)
-    if (identical(Sys.getenv("TRAVIS_CLIP"), "nodisplay"))
+    if (identical(Sys.getenv("CLIP_TYPE"), "nodisplay"))
       expect_message(dr_clipr(), msg_no_display(), fixed = TRUE)
 
     expect_true(grepl("has read/write access", msg_clipr_available()))
